@@ -6,6 +6,8 @@
 **  @brief      Main file for all the client functions and inspection
 **              flow.
 **
+**  Copyright (C) 2003-2005 Sourcefire,Inc.
+**
 **  The job of the client module is to analyze and inspect the HTTP
 **  protocol, finding where the various fields begin and end.  This must
 **  be accomplished in a stateful and stateless manner.
@@ -18,6 +20,7 @@
 **  
 **  NOTES:
 **    - 3.8.03:  Initial development.  DJR
+**    - 2.4.05:  Added tab_uri_delimiter config option.  AJM.
 */
 
 #include <stdlib.h>
@@ -112,7 +115,7 @@ static int hex_lookup[256];
 */
 static int CheckChunkEncoding(HI_SESSION *Session, u_char *start, u_char *end)
 {
-    u_int  iChunkLen   = 0;
+    int    iChunkLen   = 0;
     int    iChunkChars = 0;
     int    iCheckChunk = 1;
     u_char *ptr;
@@ -571,6 +574,17 @@ static int NextNonWhiteSpace(HI_SESSION *Session, u_char *start,
     u_char **start_sp;
     u_char **end_sp;
 
+    /*
+    **  Horizontal tab is only accepted by apache web servers, not IIS.
+    **  Some IIS exploits contain a tab (0x09) in the URI, so we don't want
+    **  to treat it as a URI delimiter and cut off the URI.
+    */
+    if ( **ptr == '\t' && !ServerConf->tab_uri_delimiter )
+    {
+        (*ptr)++;
+        return HI_SUCCESS;
+    }
+
     /*
     **  Reset the identifier, because we've just seen another space.  We
     **  should only see the identifier immediately after a space followed
