@@ -463,13 +463,12 @@ static int ps_tracker_init(PS_TRACKER *tracker)
 */
 static int ps_tracker_get(PS_TRACKER **ht, PS_HASH_KEY *key)
 {
-    PS_TRACKER new_ht;
     int iRet;
 
     *ht = (PS_TRACKER *)sfxhash_find(g_hash, (void *)key);
     if(!(*ht))
     {
-        iRet = sfxhash_add(g_hash, (void *)key, &new_ht);
+        iRet = sfxhash_add(g_hash, (void *)key, NULL);
         if(iRet == SFXHASH_OK)
         {
             *ht = (PS_TRACKER *)sfxhash_mru(g_hash);
