@@ -16,7 +16,7 @@
 ** Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */
 
-/* $Id: spp_bo.c,v 1.18.6.2 2005/10/16 18:55:29 ssturges Exp $ */
+/* $Id$ */
 /* Snort Preprocessor Plugin Source File Bo */
 
 /* spp_bo 
@@ -300,6 +300,7 @@ static int ProcessOptionList(void)
 {
     char *arg;
     int   retFlags = 0;
+    int   endList = 0;
 
     arg = strtok(NULL, CONF_SEPARATORS);
 
@@ -314,6 +315,7 @@ static int ProcessOptionList(void)
     {
         if ( !strcmp(END_LIST, arg) )
         {
+            endList = 1;
             break;
         }
 
@@ -340,6 +342,13 @@ static int ProcessOptionList(void)
         }
     }
 
+    if ( !endList )
+    {
+        FatalError("%s(%d) => Must end configuration list with %s.\n", 
+                        file_name, file_line, END_LIST);      
+        return 0;
+    }
+
     return retFlags;
 }
 
@@ -576,7 +585,7 @@ void BoFind(Packet *p, void *context)
                 }
                 if ( (drop_flags & BO_ALERT_CLIENT) && InlineMode() )
                 {
-                    p->packet_flags |= PKT_INLINE_DROP;
+                    p->packet_flags |= PKT_INLINE_DROP; 
                     InlineDrop();
                 }
                 DEBUG_WRAP(DebugMessage(DEBUG_PLUGIN, "Client packet\n"););
@@ -590,7 +599,7 @@ void BoFind(Packet *p, void *context)
                 }
                 if ( (drop_flags & BO_ALERT_SERVER) && InlineMode() )
                 {
-                    p->packet_flags |= PKT_INLINE_DROP;
+                    p->packet_flags |= PKT_INLINE_DROP; 
                     InlineDrop();
                 }
                 DEBUG_WRAP(DebugMessage(DEBUG_PLUGIN, "Server packet\n"););
@@ -604,7 +613,7 @@ void BoFind(Packet *p, void *context)
                 }
                 if ( (drop_flags & BO_ALERT_GENERAL) && InlineMode() )
                 {
-                    p->packet_flags |= PKT_INLINE_DROP;
+                    p->packet_flags |= PKT_INLINE_DROP; 
                     InlineDrop();
                 }
             }           
@@ -692,7 +701,7 @@ static int BoGetDirection(Packet *p, char *pkt_data)
         }
         if ( (drop_flags & BO_ALERT_SNORT_ATTACK) && InlineMode() )
         {
-            p->packet_flags |= PKT_INLINE_DROP;
+            p->packet_flags |= PKT_INLINE_DROP; 
             InlineDrop();
         }
 
