@@ -81,7 +81,7 @@ HTTPINSPECT_GLOBAL_CONF GlobalConf;
 **
 **  @return void
 */
-static void HttpInspect(Packet *p)
+static void HttpInspect(Packet *p, void *context)
 {
     /*
     **  IMPORTANT:
