@@ -25,6 +25,7 @@
 
 #include "mstring.h"
 #include "util.h"
+#include "parser.h"
 
 #include "sfthd.h"
 #include "sfthreshold.h"
@@ -61,7 +62,8 @@ static unsigned xatou( char * s , char * etext)
     while( *s == ' ' ) s++;
 
     if( *s == '-' ) 
-       FatalError("*** %s\n*** Invalid unsigned integer - negative sign found, input: %s\n",etext ,s );
+       FatalError("%s(%d) => *** %s\n*** Invalid unsigned integer - negative sign found, input: %s\n",
+                            file_name, file_line, etext ,s );
 
     errno = 0;
     
@@ -73,7 +75,8 @@ static unsigned xatou( char * s , char * etext)
     
     if(errno || endptr == s)
     {
-       FatalError( "*** %s\n*** Invalid integer input: %s\n",etext,s );
+       FatalError("%s(%d) => *** %s\n*** Invalid integer input: %s\n",
+                            file_name, file_line, etext, s );
     } 
 
     return val;		
@@ -113,7 +116,8 @@ void ParseThreshold2( THDX_STRUCT * thdx, char * s )
       if( argc != 8 )
       {
           /* Fatal incorrect argument count */ 
-          FatalError("Threshold-RuleOptionParse: incorrect argument count, should be 4 pairs\n");
+          FatalError("%s(%d) => Threshold-RuleOptionParse: incorrect argument count, should be 4 pairs\n",
+                            file_name, file_line);
       }
 
       for(i=0;i<argc;i++)
@@ -148,7 +152,8 @@ void ParseThreshold2( THDX_STRUCT * thdx, char * s )
             else
             {
                 /* Fatal incorrect threshold type */
-                 FatalError("Threshold-RuleOptionParse: incorrect 'type' argument \n");
+                 FatalError("%s(%d) => Threshold-RuleOptionParse: incorrect 'type' argument \n",
+                                file_name, file_line);
             }
             type_flag++;
          }
@@ -166,21 +171,24 @@ void ParseThreshold2( THDX_STRUCT * thdx, char * s )
             else
             {
                 /* Fatal incorrect threshold type */
-                 FatalError("Threshold-RuleOptionParse: incorrect tracking type\n");
+                 FatalError("%s(%d) => Threshold-RuleOptionParse: incorrect tracking type\n",
+                                file_name, file_line);
             }
             tracking_flag++;
          }
         else
          {
             /* Fatal Out Here - Unknow Option */
-            FatalError("Threshold-RuleOptionParse: unknown argument \n");
+            FatalError("%s(%d) => Threshold-RuleOptionParse: unknown argument \n",
+                            file_name, file_line);
          }
      }
 
      if( (count_flag + tracking_flag + type_flag + seconds_flag ) != 4 )
      {
          /* Fatal - incorrect argument count */
-         FatalError("Threshold-RuleOptionParse: incorrect argument count\n");
+         FatalError("%s(%d) => Threshold-RuleOptionParse: incorrect argument count\n",
+                        file_name, file_line);
      }
 }
 
@@ -213,7 +221,7 @@ void ProcessThresholdOptions(char *options)
           }
           else
           {
-             FatalError("Threshold-RuleOptionParse: unknown argument\n");
+             FatalError("%s(%d) => Threshold-RuleOptionParse: unknown argument\n",file_name, file_line);
           }
      }
      mSplitFree(&args, nargs);
@@ -235,9 +243,6 @@ void ParseSFThreshold( FILE * fp, char * rule )
      int         seconds_flag=0;
      int         type_flag=0;
      int         tracking_flag=0;
-/*     
-     int         priority_flag=0;
-*/
      int         genid_flag=0;
      int         sigid_flag=0;
      int         i;
@@ -253,9 +258,9 @@ void ParseSFThreshold( FILE * fp, char * rule )
      {
          oargs = mSplit(args[i]," ",2,&noargs,0);  /* get rule option pairs */
          
-	 if( noargs != 2 )
+	     if( noargs != 2 )
          {
-             FatalError("Threshold Parse: argument pairing error\n");
+             FatalError("%s(%d) => Threshold Parse: argument pairing error\n", file_name, file_line);
          }
 
          if( strcmp(oargs[0],"type")==0 )
@@ -275,7 +280,7 @@ void ParseSFThreshold( FILE * fp, char * rule )
             else
             {
                 /* Fatal incorrect threshold type */
-                 FatalError("Threshold-Parse: incorrect 'type' argument \n");
+                 FatalError("%s(%d) => Threshold-Parse: incorrect 'type' argument \n", file_name, file_line);
             }
             type_flag++;
          }
@@ -293,12 +298,12 @@ void ParseSFThreshold( FILE * fp, char * rule )
             else
             {
                 /* Fatal incorrect threshold type */
-                 FatalError("Threshold-Parse: incorrect tracking type\n");
+                 FatalError("%s(%d) => Threshold-Parse: incorrect tracking type\n", file_name, file_line);
             }
             tracking_flag++;
          }
 
-	 else if( strcmp(oargs[0],"count")==0 )
+	     else if( strcmp(oargs[0],"count")==0 )
          {
             thdx.count = xatou(oargs[1],"threshold: count");
             count_flag++;
@@ -315,47 +320,55 @@ void ParseSFThreshold( FILE * fp, char * rule )
             thdx.gen_id =  xatou(oargs[1],"threshold: gen_id");
             genid_flag++;
 
-	    if( oargs[1][0]== '-' ) 
-                FatalError("Threshold-Parse: gen_id < 0 not supported  '%s %s'\n",oargs[0],oargs[1]);
+	        if( oargs[1][0]== '-' ) 
+                FatalError("%s(%d) => Threshold-Parse: gen_id < 0 not supported  '%s %s'\n",
+                                    file_name, file_line, oargs[0],oargs[1]);
          }
 
          else if( strcmp(oargs[0],"sig_id")==0 )
          {
             thdx.sig_id = xatou(oargs[1],"threshold: sig_id");
             sigid_flag++;
-	    if( oargs[1][0]== '-' ) 
-                FatalError("Threshold-Parse: sig_id < 0 not supported  '%s %s'\n",oargs[0],oargs[1]);
+	        if( oargs[1][0]== '-' ) 
+                FatalError("%s(%d) => Threshold-Parse: sig_id < 0 not supported  '%s %s'\n",
+                                    file_name, file_line, oargs[0],oargs[1]);
          }
          else
          {
              /* Fatal incorrect threshold type */
-             FatalError("Threshold-Parse: unsupported option : %s %s\n",oargs[0],oargs[1]);
+             FatalError("%s(%d) => Threshold-Parse: unsupported option : %s %s\n",
+                                file_name, file_line, oargs[0],oargs[1]);
          }
      }
 
      if( (count_flag + tracking_flag + type_flag + seconds_flag + genid_flag + sigid_flag) != 6 )
      {
-	/* Fatal - incorrect argument count */
-	FatalError("Threshold-Parse: incorrect argument count\n");
+        /* Fatal - incorrect argument count */
+        FatalError("%s(%d) => Threshold-Parse: incorrect argument count\n",file_name, file_line);
      }
 
      if( sfthreshold_create( &thdx  ) )
      {
-	if( thdx.sig_id == 0 )
-	{
-	   FatalError("Global Threshold-Parse: could not create a threshold object -- only one per gen_id=%u!\n",thdx.gen_id);
-	}
-	else
-	{
-	   if( thdx.gen_id ==  0 )
-	   {
-	      FatalError("Global Threshold-Parse: could not create a threshold object -- a gen_id < 0 requires a sig_id < 0, sig_id=%u !\n",thdx.sig_id);
-	   }
-	   else
-	   {
-	      FatalError("Threshold-Parse: could not create a threshold object -- only one per sig_id=%u!\n",thdx.sig_id);
-	   }
-	}
+	    if( thdx.sig_id == 0 )
+	    {
+	       FatalError("%s(%d) => Global Threshold-Parse: could not create a threshold object "
+                            "-- only one per gen_id=%u!\n",
+                                file_name, file_line,thdx.gen_id);
+	    }
+	    else
+	    {
+	       if( thdx.gen_id ==  0 )
+	       {
+	          FatalError("%s(%d) => Global Threshold-Parse: could not create a threshold object "
+                            "-- a gen_id < 0 requires a sig_id < 0, sig_id=%u !\n",
+                                    file_name, file_line, thdx.sig_id);
+	       }
+	       else
+	       {
+	          FatalError("%s(%d) => Threshold-Parse: could not create a threshold object -- only one per sig_id=%u!\n",
+                                    file_name, file_line, thdx.sig_id);
+	       }
+	    }
      }
 
      mSplitFree(&args, nargs);
@@ -383,7 +396,7 @@ static void parseCIDR( THDX_STRUCT * thdx, char * s )
 
    if( !nargs || nargs > 2  )
    {
-       FatalError("Suppress-Parse: argument pairing error\n");
+       FatalError("%s(%d) => Suppress-Parse: argument pairing error\n", file_name, file_line);
    }
 
    /*
@@ -455,7 +468,7 @@ void ParseSFSuppress( FILE * fp, char * rule )
          oargs = mSplit(args[i]," ",2,&noargs,0);  /* get rule option pairs */
          if( noargs != 2 )
          {
-             FatalError("Suppress-Parse: argument pairing error\n");
+             FatalError("%s(%d) => Suppress-Parse: argument pairing error\n", file_name, file_line);
          }
 
          if( strcmp(oargs[0],"track")==0 )
@@ -471,7 +484,7 @@ void ParseSFSuppress( FILE * fp, char * rule )
             else
             {
                 /* Fatal incorrect threshold type */
-                 FatalError("Suppress-Parse: incorrect tracking type\n");
+                 FatalError("%s(%d) => Suppress-Parse: incorrect tracking type\n", file_name, file_line);
             }
          }
 
@@ -481,7 +494,8 @@ void ParseSFSuppress( FILE * fp, char * rule )
             thdx.gen_id = strtoul(oargs[1],&endptr,10);
             genid_flag++;
 	    if( oargs[1][0]=='-' )
-                FatalError("Suppress-Parse: gen_id < 0 is not supported, '%s %s' \n",oargs[0],oargs[1]);
+                FatalError("%s(%d) => Suppress-Parse: gen_id < 0 is not supported, '%s %s' \n",
+                                file_name, file_line, oargs[0],oargs[1]);
          }
 
          else if( strcmp(oargs[0],"sig_id")==0 )
@@ -490,7 +504,8 @@ void ParseSFSuppress( FILE * fp, char * rule )
             thdx.sig_id = strtoul(oargs[1],&endptr,10);
             sigid_flag++;
 	    if( oargs[1][0]=='-' )
-                FatalError("Suppress-Parse: sig_id < 0 is not supported, '%s %s' \n",oargs[0],oargs[1]);
+                FatalError("%s(%d) => Suppress-Parse: sig_id < 0 is not supported, '%s %s' \n",
+                                file_name, file_line, oargs[0],oargs[1]);
          }
 
          else if( strcmp(oargs[0],"ip")==0 )
@@ -502,12 +517,12 @@ void ParseSFSuppress( FILE * fp, char * rule )
      if( ( genid_flag + sigid_flag) != 2 )
      {
          /* Fatal - incorrect argument count */
-         FatalError("Suppress-Parse: incorrect argument count\n");
+         FatalError("%s(%d) => Suppress-Parse: incorrect argument count\n", file_name, file_line);
      }
 
      if( sfthreshold_create( &thdx  ) )
      {
-         FatalError("Suppress-Parse: could not create a threshold object\n");
+         FatalError("%s(%d) => Suppress-Parse: could not create a threshold object\n", file_name, file_line);
      }
 
      mSplitFree(&args, nargs);
@@ -809,7 +824,7 @@ void print_thresholding()
 	   print_thd_local(s_thd, PRINT_SUPPRESS );
 	}
 	
-	LogMessage("+------------------------------------------------------------------------------\n");
+	LogMessage("-------------------------------------------------------------------------------\n");
 	
 }
 
