@@ -1,6 +1,6 @@
 /*
 **
-** $Id: mwm.c,v 1.3.8.2 2005/07/11 14:41:41 ssturges Exp $
+** $Id$
 **
 ** mwm.c   - A Modified Wu-Manber Style Multi-Pattern Matcher
 **
@@ -1386,8 +1386,8 @@ int mwmSearch( void * pv,
                      {
                          if (++Tx < s + n)
                          {
-                             n = Tx - s;
-                             s = Tx;
+                            n--;
+                            s++;
                          }
                          else
                          {
